import { JSONSchema4, JSONSchema6, JSONSchema7 } from 'json-schema';
import { OpenAPIV3_1, OpenAPIV3 } from 'openapi-types';

type JSONSchema = JSONSchema4 | JSONSchema6 | JSONSchema7;
/**
 * @param check Data to determine if it contains a ReferenceObject (`$ref` pointer`).
 * @returns If the supplied data has a `$ref` pointer.
 */
declare function isRef(check: unknown): check is OpenAPIV3_1.ReferenceObject | OpenAPIV3.ReferenceObject;
/**
 * @param check API definition to determine if it's a 3.1 definition.
 * @returns If the definition is a 3.1 definition.
 */
declare function isOAS31(check: OpenAPIV3_1.Document | OpenAPIV3.Document): check is OpenAPIV3_1.Document;
interface User {
    [key: string]: unknown;
    keys?: {
        [key: string]: unknown;
        name: number | string;
        pass?: number | string;
        user?: number | string;
    }[];
}
type HttpMethods = OpenAPIV3_1.HttpMethods | OpenAPIV3.HttpMethods | 'delete' | 'get' | 'head' | 'options' | 'patch' | 'post' | 'put' | 'trace';
/**
 * @see {@link https://github.com/OAI/OpenAPI-Specification/blob/main/versions/3.0.3.md#oasObject}
 * @see {@link https://github.com/OAI/OpenAPI-Specification/blob/main/versions/3.1.0.md#oasObject}
 */
type OASDocument = (OpenAPIV3_1.Document | OpenAPIV3.Document) & Record<string, unknown>;
type OAS31Document = OpenAPIV3_1.Document & Record<string, unknown>;
/**
 * @see {@link https://github.com/OAI/OpenAPI-Specification/blob/main/versions/3.0.3.md#serverObject}
 * @see {@link https://github.com/OAI/OpenAPI-Specification/blob/main/versions/3.1.0.md#serverObject}
 */
type ServerObject = OpenAPIV3_1.ServerObject | OpenAPIV3.ServerObject;
/**
 * @see {@link https://github.com/OAI/OpenAPI-Specification/blob/main/versions/3.0.3.md#serverVariableObject}
 * @see {@link https://github.com/OAI/OpenAPI-Specification/blob/main/versions/3.1.0.md#serverVariableObject}
 */
type ServerVariableObject = OpenAPIV3_1.ServerVariableObject | OpenAPIV3.ServerVariableObject;
type ServerVariablesObject = Record<string, ServerVariableObject>;
type ServerVariable = Record<string, {
    default?: number | string;
}[] | Record<string, never> | number | string | {
    default?: number | string;
}>;
interface Servers {
    selected: number;
    variables: ServerVariable;
}
/**
 * @see {@link https://github.com/OAI/OpenAPI-Specification/blob/main/versions/3.0.3.md#componentsObject}
 * @see {@link https://github.com/OAI/OpenAPI-Specification/blob/main/versions/3.1.0.md#componentsObject}
 */
type ComponentsObject = OpenAPIV3_1.ComponentsObject | OpenAPIV3.ComponentsObject;
/**
 * @see {@link https://github.com/OAI/OpenAPI-Specification/blob/main/versions/3.0.3.md#pathsObject}
 * @see {@link https://github.com/OAI/OpenAPI-Specification/blob/main/versions/3.1.0.md#pathsObject}
 */
type PathsObject = OpenAPIV3_1.PathsObject | OpenAPIV3.PathsObject;
/**
 * @see {@link https://github.com/OAI/OpenAPI-Specification/blob/main/versions/3.0.3.md#pathItemObject}
 * @see {@link https://github.com/OAI/OpenAPI-Specification/blob/main/versions/3.1.0.md#pathItemObject}
 */
type PathItemObject = OpenAPIV3_1.PathItemObject | OpenAPIV3.PathItemObject;
/**
 * @see {@link https://github.com/OAI/OpenAPI-Specification/blob/main/versions/3.0.3.md#operationObject}
 * @see {@link https://github.com/OAI/OpenAPI-Specification/blob/main/versions/3.1.0.md#operationObject}
 */
type OperationObject = (OpenAPIV3_1.OperationObject | OpenAPIV3.OperationObject) & Record<string, unknown>;
/**
 * @see {@link https://github.com/OAI/OpenAPI-Specification/blob/main/versions/3.0.3.md#parameterObject}
 * @see {@link https://github.com/OAI/OpenAPI-Specification/blob/main/versions/3.1.0.md#parameterObject}
 */
type ParameterObject = OpenAPIV3_1.ParameterObject | OpenAPIV3.ParameterObject;
/**
 * @see {@link https://github.com/OAI/OpenAPI-Specification/blob/main/versions/3.0.3.md#requestBodyObject}
 * @see {@link https://github.com/OAI/OpenAPI-Specification/blob/main/versions/3.1.0.md#requestBodyObject}
 */
type RequestBodyObject = OpenAPIV3_1.RequestBodyObject | OpenAPIV3.RequestBodyObject;
/**
 * @see {@link https://github.com/OAI/OpenAPI-Specification/blob/main/versions/3.0.3.md#mediaTypeObject}
 * @see {@link https://github.com/OAI/OpenAPI-Specification/blob/main/versions/3.1.0.md#mediaTypeObject}
 */
type MediaTypeObject = OpenAPIV3_1.MediaTypeObject | OpenAPIV3.MediaTypeObject;
/**
 * @see {@link https://github.com/OAI/OpenAPI-Specification/blob/main/versions/3.0.3.md#responseObject}
 * @see {@link https://github.com/OAI/OpenAPI-Specification/blob/main/versions/3.1.0.md#responseObject}
 */
type ResponseObject = OpenAPIV3_1.ResponseObject | OpenAPIV3.ResponseObject;
/**
 * @see {@link https://github.com/OAI/OpenAPI-Specification/blob/main/versions/3.0.3.md#callbackObject}
 * @see {@link https://github.com/OAI/OpenAPI-Specification/blob/main/versions/3.1.0.md#callbackObject}
 */
type CallbackObject = OpenAPIV3_1.CallbackObject | OpenAPIV3.CallbackObject;
/**
 * @see {@link https://github.com/OAI/OpenAPI-Specification/blob/main/versions/3.0.3.md#exampleObject}
 * @see {@link https://github.com/OAI/OpenAPI-Specification/blob/main/versions/3.1.3.md#exampleObject}
 */
type ExampleObject = OpenAPIV3_1.ExampleObject | OpenAPIV3.ExampleObject;
/**
 * @see {@link https://github.com/OAI/OpenAPI-Specification/blob/main/versions/3.0.3.md#tagObject}
 * @see {@link https://github.com/OAI/OpenAPI-Specification/blob/main/versions/3.1.0.md#tagObject}
 */
type TagObject = OpenAPIV3_1.TagObject | OpenAPIV3.TagObject;
/**
 * @see {@link https://github.com/OAI/OpenAPI-Specification/blob/main/versions/3.0.3.md#headerObject}
 * @see {@link https://github.com/OAI/OpenAPI-Specification/blob/main/versions/3.1.0.md#headerObject}
 */
type HeaderObject = OpenAPIV3_1.HeaderObject | OpenAPIV3.HeaderObject;
/**
 * @see {@link https://github.com/OAI/OpenAPI-Specification/blob/main/versions/3.0.3.md#schemaObject}
 * @see {@link https://github.com/OAI/OpenAPI-Specification/blob/main/versions/3.1.0.md#schemaObject}
 */
type SchemaObject = {
    externalDocs?: unknown;
    xml?: unknown;
} & {
    $schema?: string;
    components?: OpenAPIV3_1.ComponentsObject;
    deprecated?: boolean;
    example?: unknown;
    examples?: unknown[];
    nullable?: boolean;
    readOnly?: boolean;
    writeOnly?: boolean;
    'x-readme-ref-name'?: string;
} & (OpenAPIV3.SchemaObject | OpenAPIV3_1.SchemaObject | JSONSchema);
/**
 * @param check JSON Schema object to determine if it's a non-polymorphic schema.
 * @param isPolymorphicAllOfChild If this JSON Schema object is the child of a polymorphic `allOf`.
 * @returns If the JSON Schema object is a JSON Schema object.
 */
declare function isSchema(check: unknown, isPolymorphicAllOfChild?: boolean): check is SchemaObject;
/**
 * @see {@link https://github.com/OAI/OpenAPI-Specification/blob/main/versions/3.0.3.md#securitySchemeObject}
 * @see {@link https://github.com/OAI/OpenAPI-Specification/blob/main/versions/3.1.0.md#securitySchemeObject}
 */
type SecuritySchemeObject = OpenAPIV3_1.SecuritySchemeObject | OpenAPIV3.SecuritySchemeObject;
type SecuritySchemesObject = Record<string, SecuritySchemeObject>;
type KeyedSecuritySchemeObject = SecuritySchemeObject & {
    _key: string;
    'x-default'?: number | string;
};
/**
 * @see {@link https://github.com/OAI/OpenAPI-Specification/blob/main/versions/3.0.3.md#securityRequirementObject}
 * @see {@link https://github.com/OAI/OpenAPI-Specification/blob/main/versions/3.1.0.md#securityRequirementObject}
 */
type SecurityRequirementObject = OpenAPIV3_1.SecurityRequirementObject | OpenAPIV3.SecurityRequirementObject;

export { type CallbackObject, type ComponentsObject, type ExampleObject, type HeaderObject, type HttpMethods, type JSONSchema, type KeyedSecuritySchemeObject, type MediaTypeObject, type OAS31Document, type OASDocument, type OperationObject, type ParameterObject, type PathItemObject, type PathsObject, type RequestBodyObject, type ResponseObject, type SchemaObject, type SecurityRequirementObject, type SecuritySchemeObject, type SecuritySchemesObject, type ServerObject, type ServerVariable, type ServerVariableObject, type ServerVariablesObject, type Servers, type TagObject, type User, isOAS31, isRef, isSchema };
